==> fop_0.95.dfsg.orig.tar.gz: fop-0.95/src/java/org/apache/fop/fo/properties/ShorthandParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: ShorthandParser.java 627367 2008-02-13 12:03:30Z maxberger $ */

package org.apache.fop.fo.properties;

import org.apache.fop.fo.PropertyList;
import org.apache.fop.fo.expr.PropertyException;

/**
 * Interface used to provide parsing capabilities to Properties with shorthand
 * characteristics (those with multiple components).
 */
public interface ShorthandParser {

    /**
     * @param propId the property ID in the Constants interface
     * @param maker Maker object for the Property
     * @param propertyList list of properties
     * @return Property object corresponding to propName
     */
    Property getValueForProperty(int propId,
                                 Property property,
                                 PropertyMaker maker,
                                 PropertyList propertyList) throws PropertyException;
}

==> fop_1.1.dfsg.orig.tar.gz: fop-1.1/src/java/org/apache/fop/fo/properties/ShorthandParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: ShorthandParser.java 985537 2010-08-14 17:17:00Z jeremias $ */

package org.apache.fop.fo.properties;

import org.apache.fop.fo.PropertyList;
import org.apache.fop.fo.expr.PropertyException;

/**
 * Interface used to provide parsing capabilities to Properties with shorthand
 * characteristics (those with multiple components).
 */
public interface ShorthandParser {

    /**
     * @param propId the property ID in the Constants interface
     * @param property from which value is obtained
     * @param maker Maker object for the Property
     * @param propertyList list of properties
     * @return Property object corresponding to propName
     * @throws PropertyException in case a property exception occurs
     */
    Property getValueForProperty(int propId,
                                 Property property,
                                 PropertyMaker maker,
                                 PropertyList propertyList) throws PropertyException;
}
